==> react-native-ios-utilities-4.0.0-15.tgz: package/src/RNIDummyView/RNIDummyView.tsx <==
import * as React from 'react';
import { StyleSheet } from 'react-native';

import { RNIDummyViewModule } from './RNIDummyViewModule';
import { RNIDummyNativeView } from './RNIDummyNativeView';

import type { RNIDummyViewProps } from './RNIDummyViewTypes';
import type { OnReactTagDidSetEvent } from '../types/SharedEvents';


export class RNIDummyView extends React.PureComponent<RNIDummyViewProps> {
  
  reactTag?: number;

  constructor(props: RNIDummyViewProps){
    super(props);
  };

  getProps() {
    const { 
      shouldCleanupOnComponentWillUnmount, 
      ...otherProps 
    } = this.props;

    return {
      shouldCleanupOnComponentWillUnmount: 
        shouldCleanupOnComponentWillUnmount ?? false,

      ...otherProps,
    };
  };

  componentWillUnmount(){
    this.notifyComponentWillUnmount(false);
  };

  notifyComponentWillUnmount = async (
    isManuallyTriggered: boolean = true
  ) => {
    const reactTag = this.reactTag;
    if(typeof reactTag !== 'number') return;

    await RNIDummyViewModule.notifyComponentWillUnmount(
      reactTag, 
      isManuallyTriggered
    );
  };

  private _handleOnReactTagDidSet: OnReactTagDidSetEvent = ({nativeEvent}) => {
    this.reactTag = nativeEvent.reactTag;
  };

  render(){
    const props = this.getProps();

    return React.createElement(RNIDummyNativeView, {
      ...props,
      style: styles.nativeDummyView,
      onReactTagDidSet: this._handleOnReactTagDidSet,
    });
  };
};

const styles = StyleSheet.create({
  nativeDummyView: {
    position: 'absolute',
    opacity: 0.01,
  },
});

==> react-native-ios-utilities-4.0.0-16.tgz: package/src/RNIDummyView/RNIDummyView.tsx <==
import * as React from 'react';
import { LayoutChangeEvent, StyleSheet, View } from 'react-native';

import { RNIDummyViewModule } from './RNIDummyViewModule';
import { RNIDummyNativeView } from './RNIDummyNativeView';

import type { RNIDummyViewProps } from './RNIDummyViewTypes';


export class RNIDummyView extends React.PureComponent<RNIDummyViewProps> {
  
  nativeRef?: View;

  constructor(props: RNIDummyViewProps){
    super(props);
  };

  getProps() {
    const { 
      shouldCleanupOnComponentWillUnmount, 
      ...otherProps 
    } = this.props;

    return {
      shouldCleanupOnComponentWillUnmount: 
        shouldCleanupOnComponentWillUnmount ?? false,

      ...otherProps,
    };
  };

  componentWillUnmount(){
    this.notifyComponentWillUnmount(false);
  };

  getNativeRef: () => View | undefined = () => {
    return this.nativeRef;
  };

  getNativeReactTag: () => number | undefined = () => {
    // @ts-ignore
    return this.nativeRef?.nativeTag;
  };

  notifyComponentWillUnmount = async (
    isManuallyTriggered: boolean = true
  ) => {
    const reactTag = this.getNativeReactTag();
    if(typeof reactTag !== 'number') return;

    await RNIDummyViewModule.notifyComponentWillUnmount(
      reactTag, 
      isManuallyTriggered
    );
  };

  render(){
    const props = this.getProps();

    return React.createElement(RNIDummyNativeView, {
      ...props,
      style: styles.nativeDummyView,
      // @ts-ignore
      ref: this._handleOnNativeRef,
    });
  };
};

const styles = StyleSheet.create({
  nativeDummyView: {
    position: 'absolute',
    opacity: 0.01,
  },
});
